.. _astroML_time_series:

Time Series Analysis
====================
More information will be here soon - check for updates!

Some examples of approaches to time-series analysis can be found in
:ref:`book_fig_chapter10`
